@@ -503,6 +503,21 @@ class Window:
         cv2.imwrite(f'{str_pic_path}/mark-{hwnd}.png', father_window_color)     # 保存标注的图片
         return child_window
 
+class Custom:
+    """
+    这里主要进行一些win32的功能封装，把某些常用的场景封装使用
+    """
+    @staticmethod
+    def UploadFild(file: str):
+        window = Window.FindWindow('#32770', '打开')                      # 获取上传文件主窗口
+        button = Window.FindWindow('Button', None, window)               # 获取打开按钮的句柄值
+        comboxex = Window.FindWindow('ComboBoxEx32', None, window)         # 获取子句柄combobox的句柄值
+        combox = Window.FindWindow('ComboBox', None, comboxex)
+        input_ = Window.FindWindow('Edit', None, combox)                 # 获取combobox下的输入框句柄值
+        win32api.SendMessage(input_, win32con.WM_SETTEXT, None, file)    # 进行文件输入
+        win32api.SendMessage(window, win32con.WM_COMMAND, 1, button)     # 点击打开按钮进行上传
+
+
 
 
 
